@@ -3,7 +3,7 @@ use warnings;
 
 package Badge::Depot;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # ABSTRACT: A framework for badges
 
 use Moose::Role;
@@ -78,7 +78,7 @@ Badge::Depot - A framework for badges
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-17.
+Version 0.0102, released 2015-02-18.
 
 =head1 SYNOPSIS
 
@@ -124,7 +124,7 @@ These attributes are expected to be set when the badge class returns from C<new>
 
 =head2 image_url
 
-Required. L<Uri|Types::Uri>.
+Required. L<Uri|Types::URI>.
 
 The url to the actual badge. The src attribute for the img tag when rendered to html.
 
@@ -136,7 +136,7 @@ The alternative text of the badge. The alt attribute for the img tag when render
 
 =head2 link_url
 
-Optional (but recommended). L<Uri|Types::Uri>.
+Optional (but recommended). L<Uri|Types::URI>.
 
 The url to link the badge to. The href attribute for the a tag when rendered to html. No link is created if this isn't set.
 
@@ -158,7 +158,7 @@ Returns a string with the badge rendered as markdown.
 
 =item *
 
-L<WWW::StatusBadge>
+L<WWW::StatusBadge> (an alternative to this)
 
 =back
 
